@@ -13,7 +13,7 @@ use HTTP::Response;
 use LWP::UserAgent;
 use JSON;
 
-our $VERSION = '0.092';
+our $VERSION = '0.093';
 
 our $CANNED_RESPONSE_DIR = File::Spec->catdir(
     qw{ t data Mock-LWP-UserAgent } );
@@ -26,9 +26,9 @@ $LOG_FILE_NAME
     1;
 } or $LOG_FILE_NAME = undef;
 
-my %original = map { $_ => LWP::UserAgent->can( $_ ) } qw{
-    new cookie_jar env_proxy get head post put request
-};
+## my %original = map { $_ => LWP::UserAgent->can( $_ ) } qw{
+##     new cookie_jar env_proxy get head post put request
+## };
 
 sub import {
 
@@ -247,7 +247,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015 by Thomas R. Wyant, III
+Copyright (C) 2014-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
