@@ -9,7 +9,8 @@ use Carp;
 
 
 sub ACTION_authortest {
-    my ( $self, @args ) = @_;
+##  my ( $self, @args ) = @_;
+    my ( $self ) = @_;		# Arguments not used
 
     local $ENV{AUTHOR_TESTING} = 1;
 
@@ -77,7 +78,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2011-2015 by Thomas R. Wyant, III
+Copyright (C) 2009, 2011-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
