@@ -31,8 +31,32 @@ sub distribution {
     return $self->{distribution};
 }
 
+sub meta_merge {
+    return {
+	'meta-spec'	=> {
+	    version	=> 2,
+	},
+	dynamic_config	=> 1,
+	no_index	=> {
+	    directory	=> [ qw{ inc t tools xt } ],
+	},
+	resources	=> {
+	    bugtracker	=> {
+                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack',
+                mailto  => 'wyant@cpan.org',
+            },
+	    license	=> 'http://dev.perl.org/licenses/',
+	    repository	=> {
+		type	=> 'git',
+		url	=> 'git://github.com/trwyant/perl-Astro-SpaceTrack.git',
+		web	=> 'https://github.com/trwyant/perl-Astro-SpaceTrack',
+	    },
+	}
+    };
+}
+
 sub notice {
-    my ( $self, $opt, $prompter ) = @_;
+    my ( undef, $opt ) = @_;		# Invocant unused
 
     my @possible_exes = ('SpaceTrack');
 
@@ -62,7 +86,7 @@ EOD
 }
 
 sub requires {
-    my ( $self, @extra ) = @_;
+    my ( undef, @extra ) = @_;		# Invocant unused
 
     return {
 	'Carp'			=> 0,
@@ -158,24 +182,24 @@ C<< {META_MERGE}->{build_requires} >> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<dynamic_config>, C<no_index> and
+C<resources> data.
+
 =head2 notice
 
- my @exes = $meta->notice( \%opt, \&prompter );
+ my @exes = $meta->notice( \%opt );
 
 This method prints a notice before building. It returns a list of
 executables to build.
 
-The arguments are the options hash returned by the build system, and a
-reference to a prompt routine. This reference is given the prompt and
-the default answer, and the correct argument depends on your build
-system; for ExtUtils::MakeMaker it is C<\&prompt>; for Module::Build it
-needs to be C<< sub { return $bldr->prompt( @_ ) } >>, where C<$bldr> is
-the Module::Build object.
-
-The above are general remarks.
-
-In this incarnation, the method determines which executables are to be
-installed.
+The argument is the options hash returned by the build system.
 
 =head2 requires
 
@@ -220,7 +244,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2015 by Thomas R. Wyant, III
+Copyright (C) 2010-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
